django-pays
=====================

Django integration for Pays payment gateway.

Installation
------------

Install ``django-pays`` either from source or using pip.
Run ``python manage.py migrate`` to create database models.
Add ``django_pays.urls`` to your url dispatcher.

Configuration
-------------
Create one (or more) Gatewau configuration(s) using Django Admin interface.
